==> 0.0.2.tar.gz: lib/components/senior_radio_button.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

abstract class SeniorRadioButtonTheme {
  static Color getTitleColor({ required Brightness theme, required bool isDisabled }) {
    return !isDisabled 
      ? SeniorColors.neutralColor900
      : SeniorColors.secondaryColor300;
  }

  static Color getFillColor({ required Brightness theme, required bool isDisabled }) {
    return !isDisabled
      ? SeniorColors.secondaryColor300
      : SeniorColors.primaryColor;
  }
}

class SeniorRadioButton extends StatelessWidget {
  final String title;
  final Null groupValue;
  final Null value;
  final Function(Null value) onChange;
  final bool disabled;
  final bool toggleable;

  SeniorRadioButton({
    required Key key,
    required this.title,
    required this.groupValue,
    required this.value,
    required this.onChange,
    this.disabled = false,
    this.toggleable = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 0, vertical: 8.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            child: Radio(
              key: this.key,
              groupValue: this.groupValue,
              value: this.value,
              onChanged: !this.disabled ? this.onChange : null,
              fillColor: MaterialStateColor.resolveWith(
                (state) => SeniorRadioButtonTheme.getFillColor(
                  theme: theme,
                  isDisabled: state.contains(MaterialState.disabled),
                ),  
              ),
              toggleable: this.toggleable,
            ),
            height: 16.0,
            width: 16.0,
            margin: EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          ),
          Flexible(
            child: Text(
              this.title,
              style: SeniorTypography.getTextStyle(
                token: SeniorTypographyTokens.text,
                color: SeniorRadioButtonTheme.getTitleColor(theme: theme, isDisabled: this.disabled)
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.2.0.tar.gz: lib/components/senior_radio_button.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorRadioButtonTheme {
  SeniorRadioButtonTheme._();

  static Color getTitleColor({required Brightness theme, required bool isDisabled}) {
    return isDisabled ? SeniorColors.secondaryColor300 : SeniorColors.neutralColor900;
  }

  static Color getFillColor({required Brightness theme, required bool isDisabled}) {
    return isDisabled ? SeniorColors.secondaryColor300 : SeniorColors.primaryColor;
  }
}

class SeniorRadioButton<T> extends StatelessWidget {
  final String title;
  final T groupValue;
  final T value;
  final Function(T?) onChange;
  final bool disabled;
  final bool toggleable;

  const SeniorRadioButton({
    Key? key,
    required this.title,
    required this.groupValue,
    required this.value,
    required this.onChange,
    this.disabled = false,
    this.toggleable = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 0, vertical: 8.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            child: Radio<T?>(
              key: this.key,
              groupValue: this.groupValue,
              value: this.value,
              onChanged: !this.disabled ? this.onChange : null,
              fillColor: MaterialStateColor.resolveWith(
                (state) => SeniorRadioButtonTheme.getFillColor(
                  theme: theme,
                  isDisabled: state.contains(MaterialState.disabled),
                ),
              ),
              toggleable: this.toggleable,
            ),
            height: 16.0,
            width: 16.0,
            margin: EdgeInsets.fromLTRB(0, 0, 8.0, 0),
          ),
          Flexible(
            child: Text(
              this.title,
              style: SeniorTypography.getTextStyle(
                  token: SeniorTypographyTokens.text,
                  color: SeniorRadioButtonTheme.getTitleColor(theme: theme, isDisabled: this.disabled)),
            ),
          ),
        ],
      ),
    );
  }
}
